@@ -14,16 +14,16 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from __future__ import print_function
-from __future__ import absolute_import
+
+
 import sys
 import ldap
 from .utils.common import _error
 from collections import defaultdict
 from ldif import LDIFParser, LDIFWriter
-import cStringIO
+import io
 
-from calculate.lib.cl_lang import setLocalTranslate
+from .cl_lang import setLocalTranslate
 from functools import reduce
 _ = lambda x: x
 setLocalTranslate('cl_lib3', sys.modules[__name__])
@@ -236,7 +236,7 @@ class ldapUser(_error):
             return self._dictData
         file_name = "/etc/ldap.conf"
         get_str_list = lambda x: reduce(lambda x, y: [x, y.upper()], ([x] * 2))
-        workdata = map(lambda x: (x[0], get_str_list(x[1]), len(x[1])), data)
+        workdata = [(x[0], get_str_list(x[1]), len(x[1])) for x in data] 
         dict_data = defaultdict(list)
         delimeter = (" ", "\t")
         try:
@@ -411,7 +411,7 @@ class LDIFAdd(LDIFParser):
 
     def __init__(self, ldif_data, ldap_connect):
         self.ldap_connect = ldap_connect
-        LDIFParser.__init__(self, cStringIO.StringIO(ldif_data))
+        LDIFParser.__init__(self, io.StringIO(ldif_data))
 
     def handle(self, dn, entry, controls=None):
         # (self, dn, entry, *args):
