@@ -15,11 +15,11 @@
 #  limitations under the License.
 
 import sys
-from calculate.lib.cl_template import TemplateFormat
-from calculate.lib.utils.files import process, STDOUT, getProgPath
+from ..cl_template import TemplateFormat
+from ..utils.files import process, STDOUT, getProgPath
 from os import path
 
-from calculate.lib.cl_lang import setLocalTranslate
+from ..cl_lang import setLocalTranslate
 
 _ = lambda x: x
 setLocalTranslate('cl_lib3', sys.modules[__name__])
