@@ -14,15 +14,16 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+
 import sys
 import re
 import os
 from os import path
-from calculate.lib.utils.tools import (Cachable, GenericFs, unique)
-import files
+from .tools import (Cachable, GenericFs, unique)
+from . import files
 from time import sleep
 
-from calculate.lib.cl_lang import setLocalTranslate
+from ..cl_lang import setLocalTranslate
 
 setLocalTranslate('cl_lib3', sys.modules[__name__])
 
@@ -61,7 +62,7 @@ def countPartitions(devname):
     return len([x for x in sysfs.listdir(syspath) if x.startswith(device_name)])
 
 
-class LvmCommand(object):
+class LvmCommand():
     @property
     def lvm_cmd(self):
         return files.getProgPath('/sbin/lvm')
@@ -130,7 +131,7 @@ class Lvm(Cachable):
     LVM информация
     """
     def __init__(self, commander):
-        super(Lvm, self).__init__()
+        super().__init__()
         self.commander = commander
 
     @property
@@ -197,18 +198,16 @@ def lspci(filtername=None, shortInfo=False):
     lspciProg = files.checkUtils('/usr/sbin/lspci')
     processLsPci = files.process(lspciProg, "-m")
     retData = {}
-    for device in map(lambda x: x.groups(),
-                      filter(lambda x: x,
-                             map(reData.search,
-                                 filter(filterfunc,
-                                        processLsPci)))):
+    for device in (x.groups() for x 
+            in (reData.search(y) for y 
+                in processLsPci if filterfunc(y)) if x):
         retData[device[0]] = {'type': sfunc(device[1]),
                               'vendor': sfunc(device[2]),
                               'name': sfunc(device[3])}
     return retData
 
 
-class UdevAdmNull(object):
+class UdevAdmNull():
     def info_property(self, path=None, name=None):
         return {}
 
@@ -274,7 +273,7 @@ class UdevAdm(UdevAdmNull):
                       "--timeout=%d" % timeout).success()
 
 
-class Udev(object):
+class Udev():
     """
     Объект возвращающий преобразованную или кэшированную информацию о системе
     из udev
@@ -318,7 +317,6 @@ class Udev(object):
                 self.path_cache[devname] = data
             return data
         else:
-            # print "fromCache",keyCache
             return cache[value]
 
     def get_block_devices(self):
@@ -525,7 +523,7 @@ def humanreadableSize(size, compsize=0):
               ((1024 ** 3), "G", True),
               ((1024 ** 4), "T", True),
               ((1024 ** 5), "P", True))
-    suffix = filter(lambda x: abs(size-compsize) > x[0], suffix)
+    suffix = [x for x in suffix if abs(size-compsize) > x[0]]
     if suffix:
         suffix = suffix[-1]
         printSize = int(size / (float(suffix[0]) / 10))
@@ -556,7 +554,7 @@ def getPartitionSize(syspath=None, name=None, inBytes=False):
     return ""
 
 
-class MdadmCommand(object):
+class MdadmCommand():
     @property
     def mdadm_cmd(self):
         return files.getProgPath('/sbin/mdadm')
@@ -571,7 +569,7 @@ class MdadmCommand(object):
             return ""
         return files.process(self.mdadm_cmd, "--zero-superblock", dev).success()
 
-class Raid(object):
+class Raid():
     def __init__(self, commander):
         self.commander = commander
 
@@ -619,7 +617,7 @@ def loadEfiVars():
     """
     Load module with efivars
     """
-    import mount
+    from . import mount
 
     modprobe = files.getProgPath('/sbin/modprobe')
     if not sysfs.exists(sysfs.Path.Efi) and modprobe:
@@ -632,7 +630,7 @@ def loadEfiVars():
         mtab.rebuildCache()
 
 
-class DeviceFs(object):
+class DeviceFs():
     """
     Файловая система, используемая для описания /sys, /dev
     """
@@ -677,7 +675,7 @@ class Sysfs(DeviceFs):
     """
     base_dn = "/sys"
 
-    class Path(object):
+    class Path():
         Firmware = "firmware"
         Efi = path.join(Firmware, "efi")
         Efivars = path.join(Efi, "efivars")
@@ -731,7 +729,7 @@ class HwinfoTimeout(HwinfoError):
 class HwinfoNotExists(HwinfoError):
     pass
 
-class Hwinfo(object):
+class Hwinfo():
     """
     Объект получения информации из hwinfo
     """
