@@ -14,11 +14,11 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from __future__ import absolute_import
+
 import sys
 import os
 import re
-from calculate.lib.utils.tools import SingletonParam
+from .tools import SingletonParam
 from . import files
 from . import device
 import errno
@@ -29,7 +29,7 @@ import tempfile
 from functools import reduce
 
 _ = lambda x: x
-from calculate.lib.cl_lang import setLocalTranslate
+from ..cl_lang import setLocalTranslate
 
 setLocalTranslate('cl_lib3', sys.modules[__name__])
 
@@ -79,7 +79,7 @@ class MountHelperError(Exception):
 class MountHelperNotFound(MountHelperError):
     pass
 
-class MountHelper(object):
+class MountHelper():
     """Data reader for fstab"""
     data_file = '/etc/fstab'
     NAME, DIR, TYPE, OPTS, FREQ, PASSNO = range(0, 6)
@@ -103,10 +103,8 @@ class MountHelper(object):
         def setlen(ar):
             return ar[:6] + [""] * (6 - len(ar))
 
-        self.cache = \
-            map(lambda x: setlen(map(lambda y: y.strip(), x.split())),
-                filter(lambda x: x.strip() and not x.lstrip().startswith("#"),
-                       self._readdata().split('\n')))
+        self.cache = [setlen([y.strip() for y in x.split()]) for x 
+            in self._readdata().split('\n') if x.strip() and not x.lstrip().startswith("#")]
         for data in self.cache:
             convertDev = lambda x: (os.path.realpath(x)
                                     if x.startswith('/') else x)
@@ -114,7 +112,7 @@ class MountHelper(object):
                 name=convertDev(self.dictUUID.get(data[0], data[0]))
             ).get('DEVNAME', data[0])
             data[1] = data[1] if data[2] != "swap" else "swap"
-        self.rotateCache = zip(*self.cache)
+        self.rotateCache = list(zip(*self.cache))
 
     def getBy(self, what=DIR, where=NAME, _in=None, eq=None,
               contains=None, noteq=None, allentry=False):
@@ -127,7 +125,7 @@ class MountHelper(object):
             filterfunc = lambda x: contains in x[where]
         else:
             filterfunc = lambda x: x[where] != noteq
-        res = map(lambda x: x[what], filter(filterfunc, self.cache))
+        res = [x[what] for x in self.cache if filterfunc(x)]
         if allentry:
             return res
         else:
@@ -135,10 +133,10 @@ class MountHelper(object):
 
     def getFields(self, *fields):
         """Get all data by specifie fields"""
-        return zip(*reduce(lambda x, y: x + [self.rotateCache[y]], fields, []))
+        return list(zip(*reduce(lambda x, y: x + [self.rotateCache[y]], fields, [])))
 
     def isReadonly(self, what=DIR, eq=None):
-        for data in filter(lambda x: x[what] == eq, self.cache):
+        for data in (x for x in self.cache if x[what] == eq):
             opts = data[self.OPTS].split(',')
             if "ro" in opts:
                 return True
@@ -161,12 +159,11 @@ class MountHelper(object):
             filterfunc = lambda x: x[what] == eq
         else:
             filterfunc = lambda x: x[what] != noteq
-        return bool(filter(filterfunc, self.cache))
+        return bool([x for x in self.cache if filterfunc(x)])
 
 
-class FStab(MountHelper):
+class FStab(MountHelper, metaclass=SingletonParam):
     """Data reader for fstab"""
-    __metaclass__ = SingletonParam
     data_file = '/etc/fstab'
 
 
@@ -179,7 +176,7 @@ class DiskSpaceError(Exception):
     pass
 
 
-class DiskSpace(object):
+class DiskSpace():
     def __init__(self):
         self.df_cmd = files.getProgPath('/bin/df')
 
@@ -194,7 +191,7 @@ class DiskSpace(object):
             data = p.read().strip()
             lines = data.split('\n')
             if len(lines) >= 2:
-                cols = filter(None, lines[1].split())
+                cols = [x for x in lines[1].split() if x]
                 if len(cols) == 6:
                     return int(cols[3])
             raise DiskSpaceError(_("Wrong df output:\n%s") % data)
@@ -204,12 +201,13 @@ class DiskSpace(object):
 
 def commonPath(*paths):
     """Return common path from list of paths"""
-    paths = map(lambda x: os.path.normpath(x).split('/'), paths)
-    res = map(lambda x: x[0],
-              filter(lambda x: filter(lambda y: x[0] == y, x[1:]), zip(*paths)))
+    paths = [os.path.normpath(x).split('/') for x in paths]
+    res = [x[0] for x in zip(*paths) if [y for y in x[1:] if x[0] == y]]
     return "/".join(res)
 
 
+
+
 def childMounts(pathname):
     """Get all mount points which contain path"""
     if pathname != "none":
@@ -221,11 +219,8 @@ def childMounts(pathname):
         return ""
     with open(mtabFile) as f:
         return reduce(lambda x, y: x + [y],
-                      filter(lambda x: commonPath(absPath, x[0]) == absPath or \
-                                       commonPath(absPath, x[1]) == absPath,
-                             map(lambda x: [x[0], x[1]],
-                                 map(lambda x: x.split(" "), f))),
-                      [])
+            (x for x in ([y[0], y[1]] for y in (z.split(" ") for z in f)) 
+                if commonPath(absPath, x[0]) == absPath or commonPath(absPath, x[1]) == absPath), [])
 
 class MountError(Exception):
     pass
@@ -275,7 +270,7 @@ def try_umount(target):
 class BtrfsError(Exception):
     pass
 
-class Btrfs(object):
+class Btrfs():
     """
     Получение информации о btrfs
     """
